@@ -858,9 +858,10 @@ class DSLibrary(object):
             if open_args.get("sql") or open_args.get("sql_table"):
                 sql = open_args.pop("sql", None)
                 table = open_args.pop("sql_table", None)
-                if table:
-                    sql = f"SELECT * from {sql_enquote_id(table, dotted=True)}"
                 db_conn = self.get_sql_connection(resource_name, **open_args)
+                if table:
+                    flavor = getattr(db_conn, "_flavor") if hasattr(db_conn, "_flavor") else None
+                    sql = f"SELECT * from {sql_enquote_id(table, dotted=True, mode=flavor)}"
                 try:
                     c = db_conn.cursor()
                     c.execute(sql)
