@@ -142,7 +142,14 @@ class DSLibraryViaMMLibrary(DSLibrary):
                 return io.StringIO(data[filename])
             return io.BytesIO((data[filename]).encode("utf-8"))
         def finalize(fh):
-            data = json.loads(reader() or b'{}')
+            raw = b''
+            try:
+                raw = reader()
+                data = json.loads(raw or b'{}')
+            except ValueError as err:
+                import warnings
+                warnings.warn(f"Incompatible mixed use of mmlibrary.save_temporary_data() and dslibrary.open_run_data(): could not add to non-JSON data: sample={str(raw[:40])}, err={err}")
+                data = {}
             if "a" in mode:
                 if filename not in data:
                     data[filename] = ""
