@@ -517,6 +517,20 @@ class TestFront(unittest.TestCase):
         r = MyInst().load_dataframe("x", dask=False, format="csv", format_options={}, fallback_to_text=False)
         assert list(r.x) == [1, 2]
 
+    def test_load_dataframe__hello(self):
+        """
+        The default behavior for csv.Sniffer is very strange.  It will detect "L" as the delimiter, simply because
+        that letter occurs twice.
+        """
+        inst = self
+        class MyInst(DSLibrary):
+            def _opener(self, path: str, mode: str, **kwargs):
+                inst.assertEqual(path, "x")
+                inst.assertEqual(kwargs, {})
+                return io.StringIO("HELLO")
+        r = MyInst().load_dataframe("x", dask=False, format="csv", format_options={}, fallback_to_text=False)
+        assert list(r.HELLO) == []
+
     def test_load_dataframe__empty_cell_case(self):
         class MyInst(DSLibrary):
             def _opener(self, path: str, mode: str, **kwargs):
